@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyutils.c 7500 2007-02-07 22:24:20Z yeti-dn $
+ *  @(#) $Id: gwyutils.c 8914 2008-12-30 12:45:34Z yeti-dn $
  *  Copyright (C) 2003-2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -270,6 +270,96 @@ gwy_strisident(const gchar *s,
     return TRUE;
 }
 
+/**
+ * gwy_stramong:
+ * @str: A string to find.
+ * @...: %NULL-terminated list of string to compare @str with.
+ *
+ * Checks whether a string is equal to any from given list.
+ *
+ * Returns: Zero if @str does not equal to any string from the list, nozero
+ *          othwerise.  More precisely, the position + 1 of the first string
+ *          @str equals to is returned in the latter case.
+ *
+ * Since: 2.11
+ **/
+guint
+gwy_stramong(const gchar *str,
+             ...)
+{
+    va_list ap;
+    const gchar *s;
+    guint i = 1;
+
+    va_start(ap, str);
+    while ((s = va_arg(ap, const gchar*))) {
+        if (gwy_strequal(str, s)) {
+            va_end(ap);
+            return i;
+        }
+        i++;
+    }
+    va_end(ap);
+
+    return 0;
+}
+
+/**
+ * gwy_memmem:
+ * @haystack: Memory block to search in.
+ * @haystack_len: Size of @haystack, in bytes.
+ * @needle: Memory block to find.
+ * @needle_len: Size of @needle, in bytes.
+ *
+ * Find a block of memory in another block of memory.
+ *
+ * This function is very similar to strstr(), except that it works with
+ * arbitrary memory blocks instead of %NUL-terminated strings.
+ *
+ * If @needle_len is zero, @haystack is always returned.
+ *
+ * On GNU systems with glibc at least 2.1 this is a just a trivial memmem()
+ * wrapper.  On other systems it emulates memmem() behaviour.
+ *
+ * Returns: Pointer to the first byte of memory block in @haystack that matches
+ *          @needle; %NULL if no such block exists.
+ *
+ * Since: 2.12
+ **/
+gpointer
+gwy_memmem(gconstpointer haystack,
+           gsize haystack_len,
+           gconstpointer needle,
+           gsize needle_len)
+{
+#undef HAVE_MEMMEM
+#ifdef HAVE_MEMMEM
+    return memmem(haystack, haystack_len, needle, needle_len);
+#else
+    const guchar *h = haystack;
+    const guchar *s, *p;
+    guchar n0;
+
+    /* Empty needle can be found anywhere */
+    if (!needle_len)
+        return (gpointer)haystack;
+
+    /* Needle that doesn't fit cannot be found anywhere */
+    if (needle_len > haystack_len)
+        return NULL;
+
+    /* The general case */
+    n0 = *(const guchar*)needle;
+    s = h + haystack_len - needle_len;
+    for (p = h; p <= s; p = memchr(p, n0, s-p + 1)) {
+        if (memcmp(p, needle, needle_len) == 0)
+            return (gpointer)p;
+        p++;
+    }
+    return NULL;
+#endif
+}
+
 /**
  * gwy_file_get_contents:
  * @filename: A file to read contents of.
@@ -834,10 +924,10 @@ gwy_object_set_or_reset(gpointer object,
 
     pspec = g_object_class_list_properties(klass, &nspec);
     already_set = g_newa(gboolean, nspec);
-    memset(already_set, 0, nspec*sizeof(gboolean));
+    gwy_clear(already_set, nspec);
 
-    memset(&cur_value, 0, sizeof(GValue));
-    memset(&new_value, 0, sizeof(GValue));
+    gwy_clear(&cur_value, 1);
+    gwy_clear(&new_value, 1);
 
     va_start(ap, type);
     for (name = va_arg(ap, gchar*); name; name = va_arg(ap, gchar*)) {
@@ -878,7 +968,7 @@ gwy_object_set_or_reset(gpointer object,
     }
     va_end(ap);
 
-    memset(&value, 0, sizeof(GValue));
+    gwy_clear(&value, 1);
     for (i = 0; i < nspec; i++) {
         if (already_set[i]
             || !(pspec[i]->flags & G_PARAM_WRITABLE)
@@ -980,6 +1070,20 @@ gwy_object_set_or_reset(gpointer object,
  * errors and in similar situations.  Under normal circumstances, use CLAMP().
  **/
 
+/**
+ * gwy_clear:
+ * @array: Pointer to an array of values to clear.
+ *         This argument may be evaluated several times.
+ * @n: Number of items to clear.
+ *
+ * Fills memory block representing an array with zeroes.
+ *
+ * This is a shorthand for memset, with the number of bytes to fill calculated
+ * from the type of the pointer.
+ *
+ * Since: 2.12
+ **/
+
 /**
  * gwy_object_unref:
  * @obj: A pointer to #GObject or %NULL (must be an l-value).
