@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyaxis.c 8816 2008-12-04 13:37:47Z yeti-dn $
+ *  @(#) $Id: gwyaxis.c 8995 2009-02-06 10:13:08Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1059,7 +1059,7 @@ gwy_axis_format_label(GwyAxis *axis,
     if ((axis->magnification_string && axis->magnification_string->len > 0)
         || *units) {
         g_string_append(plotlabel, " [");
-        if (axis->magnification_string)
+        if (axis->magnification_string && axis->magnification_string->len)
             g_string_append(plotlabel, axis->magnification_string->str);
         else
             g_string_append(plotlabel, units);
@@ -2029,7 +2029,7 @@ gwy_axis_export_vector(GwyAxis *axis, gint xmin, gint ymin,
     units = gwy_si_unit_get_string(axis->unit, GWY_SI_UNIT_FORMAT_MARKUP);
     if (axis->magnification_string->len > 0 || *units) {
         g_string_append(plotlabel, " [");
-        if (axis->magnification_string)
+        if (axis->magnification_string->len)
             g_string_append(plotlabel, axis->magnification_string->str);
         else
             g_string_append(plotlabel, units);
