@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwygraphmodel.c 8576 2007-09-24 12:58:40Z yeti-dn $
+ *  @(#) $Id: gwygraphmodel.c 8884 2008-12-28 12:17:44Z yeti-dn $
  *  Copyright (C) 2004-2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -392,9 +392,9 @@ gwy_graph_model_init(GwyGraphModel *gmodel)
 
     gmodel->title = g_string_new("Graph");
     gmodel->bottom_label = g_string_new("x");
-    gmodel->top_label = g_string_new("");
+    gmodel->top_label = g_string_new(NULL);
     gmodel->left_label = g_string_new("y");
-    gmodel->right_label = g_string_new("");
+    gmodel->right_label = g_string_new(NULL);
 
     gmodel->label_position = GWY_GRAPH_LABEL_NORTHEAST;
     gmodel->grid_type = GWY_GRAPH_GRID_AUTO;
@@ -1582,9 +1582,9 @@ gwy_graph_model_export_ascii(GwyGraphModel *model,
     switch (export_style) {
         case GWY_GRAPH_MODEL_EXPORT_ASCII_PLAIN:
         case GWY_GRAPH_MODEL_EXPORT_ASCII_ORIGIN:
-        labels = g_string_new("");
-        descriptions = g_string_new("");
-        units = g_string_new("");
+        labels = g_string_new(NULL);
+        descriptions = g_string_new(NULL);
+        units = g_string_new(NULL);
         for (i = 0; i < model->curves->len; i++) {
             cmodel = g_ptr_array_index(model->curves, i);
             if (export_metadata)
@@ -1653,9 +1653,9 @@ gwy_graph_model_export_ascii(GwyGraphModel *model,
         break;
 
         case GWY_GRAPH_MODEL_EXPORT_ASCII_CSV:
-        labels = g_string_new("");
-        descriptions = g_string_new("");
-        units = g_string_new("");
+        labels = g_string_new(NULL);
+        descriptions = g_string_new(NULL);
+        units = g_string_new(NULL);
         for (i = 0; i < model->curves->len; i++) {
             cmodel = g_ptr_array_index(model->curves, i);
             if (export_metadata)
