@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: dwt.c 6809 2006-10-17 18:43:50Z yeti-dn $
+ *  @(#) $Id: dwt.c 8874 2008-12-28 12:16:22Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -738,6 +738,7 @@ gwy_data_line_dwt_real(GwyDataLine *dline,
     dline->data += 1;    /* XXX: hack, pwt() uses 1-based indexing */
 }
 
+/* XXX: uses 1-based indexing! */
 static GwyDataLine*
 pwt(GwyDWTFilter *wt,
     GwyDataLine *dline,
@@ -751,7 +752,7 @@ pwt(GwyDWTFilter *wt,
     g_return_val_if_fail(n >= 4, NULL);
     data = dline->data;
     wdata = wt->wksp->data;
-    memset(wdata + 1, 0, n*sizeof(gdouble));
+    gwy_clear(wdata + 1, n);
 
     nmod = wt->ncof*n;
     n1 = n-1;
