@@ -1,5 +1,5 @@
 /*
- *  $Id: apefile.c 8625 2007-10-10 20:03:12Z yeti-dn $
+ *  $Id: apefile.c 8950 2009-01-02 12:00:56Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -26,11 +26,9 @@
  * [FILE-MAGIC-FREEDESKTOP]
  * <mime-type type="application/x-ape-spm">
  *   <comment>APE SPM data</comment>
- *   <magic priority="50">
+ *   <magic priority="80">
  *     <match type="string" offset="234" value="APERES"/>
  *   </magic>
- *   <glob pattern="*.dat"/>
- *   <glob pattern="*.DAT"/>
  * </mime-type>
  **/
 
@@ -233,6 +231,10 @@ apefile_load(const gchar *filename,
     apefile.topo_means = gwy_get_guint16_le(&p);
     apefile.optical_means = gwy_get_guint16_le(&p);
     apefile.error_means = gwy_get_guint16_le(&p);
+    /*
+    g_printerr("%04x %04x %04x\n",
+               apefile.topo_means, apefile.optical_means, apefile.error_means);
+               */
     apefile.channels = gwy_get_guint32_le(&p);
     apefile.ndata = 0;
     for (b = apefile.channels; b; b = b >> 1)
