@@ -1,5 +1,5 @@
 /*
- *  $Id: metropro.c 7754 2007-03-24 11:07:24Z yeti-dn $
+ *  $Id: metropro.c 8950 2009-01-02 12:00:56Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -22,11 +22,9 @@
  * [FILE-MAGIC-FREEDESKTOP]
  * <mime-type type="application/x-zygo-spm">
  *   <comment>Zygo SPM data</comment>
- *   <magic priority="50">
+ *   <magic priority="80">
  *     <match type="string" offset="0" value="\x88\x1b\x03\x6f"/>
  *   </magic>
- *   <glob pattern="*.dat"/>
- *   <glob pattern="*.DAT"/>
  * </mime-type>
  **/
 
@@ -246,7 +244,7 @@ mprofile_load(const gchar *filename,
         return NULL;
     }
 
-    key = g_string_new("");
+    key = g_string_new(NULL);
     container = gwy_container_new();
     for (i = 0; i < n; i++) {
         if (i < mprofile.nbuckets) {
