@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: nanoscope.c 8916 2008-12-30 12:48:54Z yeti-dn $
+ *  @(#) $Id: nanoscope.c 8989 2009-01-30 14:57:38Z yeti-dn $
  *  Copyright (C) 2004-2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -137,7 +137,7 @@ static GwyModuleInfo module_info = {
     N_("Imports Veeco (Digital Instruments) Nanoscope data files, "
        "version 3 or newer."),
     "Yeti <yeti@gwyddion.net>",
-    "0.22",
+    "0.23",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -516,6 +516,12 @@ hash_to_data_field(GHashTable *hash,
                 yres = gyres;
             }
         }
+        else {
+            /* Reported by Peter Eaton.  No test case that would contradict
+             * this known. */
+            yreal *= yres;
+            yreal /= xres;
+        }
 
         if (err_DIMENSION(error, xres) || err_DIMENSION(error, yres))
             return NULL;
