@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: sis.c 7784 2007-03-28 19:58:52Z yeti-dn $
+ *  @(#) $Id: sis.c 8950 2009-01-02 12:00:56Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -22,7 +22,7 @@
  * [FILE-MAGIC-FREEDESKTOP]
  * <mime-type type="application/x-sis-spm">
  *   <comment>SIS SPM data</comment>
- *   <magic priority="50">
+ *   <magic priority="80">
  *     <match type="string" offset="0" value="SIS&amp;STB  SIScan"/>
  *   </magic>
  *   <glob pattern="*.sis"/>
@@ -510,7 +510,7 @@ sis_load(const gchar *filename,
                                            NULL, g_free);
     if (sis_real_load(buffer, size, &sisfile, error)) {
         data = gwy_container_new();
-        key = g_string_new("");
+        key = g_string_new(NULL);
         for (i = 0; i < sisfile.nchannels; i++) {
             for (j = 0; j < sisfile.channels[i].nimages; j++) {
                 image = sisfile.channels[i].images + j;
