@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: spml.c 7547 2007-02-20 09:05:54Z yeti-dn $
+ *  @(#) $Id: spml.c 8948 2009-01-02 11:58:58Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -36,15 +36,19 @@
  */
 /*#define DEBUG*/
 
+/* XXX: The typical length of a XML declaration is about 40 bytes.  So while
+ * there can be more stuff before <SPML than 60 bytes, we have to find a
+ * compromise between generality and efficiency.  It's the SPML guys' fight,
+ * they should have created a more easily detectable format... */
 /**
  * [FILE-MAGIC-FREEDESKTOP]
  * <mime-type type="application/x-spml-spm">
  *   <comment>SPML data</comment>
- *   <magic priority="50">
- *     <match type="string" offset="0" value="&lt;SPML"/>
+ *   <magic priority="80">
+ *     <match type="string" offset="0" value="&lt;?xml">
+ *       <match type="string" offset="20:60" value="&lt;SPML"/>
+ *     </match>
  *   </magic>
- *   <glob pattern="*.xml"/>
- *   <glob pattern="*.XML"/>
  * </mime-type>
  **/
 
@@ -973,17 +977,15 @@ spml_load(const gchar *filename)
                 /* create and allocate datafield of given dimensions and given physical
                    dimensions */
                 if (rotate == 90) {
-                    dfield =
-                    GWY_DATA_FIELD(gwy_data_field_new
+                    dfield = gwy_data_field_new
                                    (dimensions[1], dimensions[0],
                                     y_dimen * pow10(y_power10),
-                                    x_dimen * pow10(x_power10), FALSE));
+                                    x_dimen * pow10(x_power10), FALSE);
                 } else {
-                dfield =
-                    GWY_DATA_FIELD(gwy_data_field_new
+                dfield = gwy_data_field_new
                                    (dimensions[0], dimensions[1],
                                     x_dimen * pow10(x_power10),
-                                    y_dimen * pow10(y_power10), FALSE));
+                                    y_dimen * pow10(y_power10), FALSE);
                 }
                 gwy_debug("X real width: %f", x_dimen * pow10(x_power10));
                 gwy_debug("X real_width_height: %f", x_dimen);
@@ -1027,7 +1029,7 @@ spml_load(const gchar *filename)
 
                 if (object == NULL) {
                     /* create gwyddion container */
-                    object = GWY_CONTAINER(gwy_container_new());
+                    object = gwy_container_new();
                 }
                 /* put datachannel into container */
                 gwy_channel_location =
