@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: line.c 8517 2007-09-09 13:07:36Z yeti-dn $
- *  Copyright (C) 2003-2007 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: line.c 8858 2008-12-23 12:57:03Z yeti-dn $
+ *  Copyright (C) 2003-2008 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -45,7 +45,8 @@ enum {
 
 enum {
     PROP_0,
-    PROP_LINE_NUMBERS
+    PROP_LINE_NUMBERS,
+    PROP_THICKNESS
 };
 
 typedef struct _GwyLayerLine          GwyLayerLine;
@@ -67,6 +68,7 @@ struct _GwyLayerLine {
 
     /* Properties */
     gboolean line_numbers;
+    gint thickness;
 
     /* Dynamic state */
     gint endpoint;  /* We need information which endpoint is moving; old
@@ -133,6 +135,8 @@ static gboolean   gwy_layer_line_button_released (GwyVectorLayer *layer,
                                                   GdkEventButton *event);
 static void       gwy_layer_line_set_line_numbers(GwyLayerLine *layer,
                                                   gboolean line_numbers);
+static void       gwy_layer_line_set_thickness   (GwyLayerLine *layer,
+                                                  gint thickness);
 static void       gwy_layer_line_realize         (GwyDataViewLayer *dlayer);
 static void       gwy_layer_line_unrealize       (GwyDataViewLayer *dlayer);
 static gint       gwy_layer_line_near_line       (GwyVectorLayer *layer,
@@ -156,7 +160,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Layer allowing selection of arbitrary straight lines."),
     "Yeti <yeti@gwyddion.net>",
-    "3.0",
+    "3.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -210,6 +214,15 @@ gwy_layer_line_class_init(GwyLayerLineClass *klass)
                               "Whether to attach line numbers to the lines.",
                               TRUE,
                               G_PARAM_READWRITE));
+
+    g_object_class_install_property
+        (gobject_class,
+         PROP_THICKNESS,
+         g_param_spec_int("thickness",
+                          "Line thickness",
+                          "Thickness marked by end-point markers.",
+                          -1, 1024, 1,
+                          G_PARAM_READWRITE));
 }
 
 static void
@@ -223,6 +236,7 @@ static void
 gwy_layer_line_init(GwyLayerLine *layer)
 {
     layer->line_numbers = TRUE;
+    layer->thickness = 1;
 }
 
 static void
@@ -238,6 +252,10 @@ gwy_layer_line_set_property(GObject *object,
         gwy_layer_line_set_line_numbers(layer, g_value_get_boolean(value));
         break;
 
+        case PROP_THICKNESS:
+        gwy_layer_line_set_thickness(layer, g_value_get_int(value));
+        break;
+
         default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -257,6 +275,10 @@ gwy_layer_line_get_property(GObject*object,
         g_value_set_boolean(value, layer->line_numbers);
         break;
 
+        case PROP_THICKNESS:
+        g_value_set_int(value, layer->thickness);
+        break;
+
         default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -287,6 +309,32 @@ gwy_layer_line_set_line_numbers(GwyLayerLine *layer,
     g_object_notify(G_OBJECT(layer), "line-numbers");
 }
 
+static void
+gwy_layer_line_set_thickness(GwyLayerLine *layer,
+                         gint thickness)
+{
+    GwyVectorLayer *vector_layer;
+    GtkWidget *parent;
+
+    g_return_if_fail(GWY_IS_LAYER_LINE(layer));
+    vector_layer = GWY_VECTOR_LAYER(layer);
+    parent = GWY_DATA_VIEW_LAYER(layer)->parent;
+
+    thickness = MAX(thickness, 0);
+
+    if (thickness == layer->thickness)
+        return;
+
+    if (parent && GTK_WIDGET_REALIZED(parent))
+        gwy_layer_line_undraw(vector_layer, parent->window,
+                              GWY_RENDERING_TARGET_SCREEN);
+    layer->thickness = thickness;
+    if (parent && GTK_WIDGET_REALIZED(parent))
+        gwy_layer_line_draw(vector_layer, parent->window,
+                            GWY_RENDERING_TARGET_SCREEN);
+    g_object_notify(G_OBJECT(layer), "thickness");
+}
+
 static void
 gwy_layer_line_draw(GwyVectorLayer *layer,
                     GdkDrawable *drawable,
@@ -322,6 +370,9 @@ gwy_layer_line_draw_object(GwyVectorLayer *layer,
     has_object = gwy_selection_get_object(layer->selection, i, xy);
     g_return_if_fail(has_object);
 
+    gwy_data_view_get_real_data_sizes(data_view, &xreal, &yreal);
+    gdk_drawable_get_size(drawable, &width, &height);
+
     switch (target) {
         case GWY_RENDERING_TARGET_SCREEN:
         gwy_data_view_coords_real_to_xy(data_view, xy[0], xy[1], &xi0, &yi0);
@@ -331,8 +382,6 @@ gwy_layer_line_draw_object(GwyVectorLayer *layer,
         break;
 
         case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
-        gwy_data_view_get_real_data_sizes(data_view, &xreal, &yreal);
-        gdk_drawable_get_size(drawable, &width, &height);
         xi0 = floor(xy[0]*width/xreal);
         yi0 = floor(xy[1]*height/yreal);
         xi1 = floor(xy[2]*width/xreal);
@@ -346,6 +395,65 @@ gwy_layer_line_draw_object(GwyVectorLayer *layer,
     gdk_draw_line(drawable, layer->gc, xi0, yi0, xi1, yi1);
 
     layer_line = GWY_LAYER_LINE(layer);
+
+    if (layer_line->thickness > 1) {
+        gint xres, yres, xl0, yl0, xl1, yl1;
+        gdouble xd, yd, h;
+
+        /* Calculate orthogonal line in terms of samples, that differs from
+         * display pixels -- and either can be non-square. */
+        gwy_data_view_get_pixel_data_sizes(data_view, &xres, &yres);
+        xd = (xy[3] - xy[1])/yreal*yres;
+        yd = (xy[0] - xy[2])/xreal*xres;
+        h = hypot(xd, yd);
+        xd *= layer_line->thickness/h *xreal/xres/2;
+        yd *= layer_line->thickness/h *yreal/yres/2;
+
+        switch (target) {
+            case GWY_RENDERING_TARGET_SCREEN:
+            gwy_data_view_coords_real_to_xy(data_view, xy[0] + xd, xy[1] + yd,
+                                            &xl0, &yl0);
+            gwy_data_view_coords_real_to_xy(data_view, xy[0] - xd, xy[1] - yd,
+                                            &xl1, &yl1);
+            gwy_data_view_coords_xy_cut_line(data_view, &xl0, &yl0, &xl1, &yl1);
+            break;
+
+            case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
+            xl0 = floor((xy[0] + xd)*width/xreal);
+            yl0 = floor((xy[1] + xd)*height/yreal);
+            xl1 = floor((xy[0] - xd)*width/xreal);
+            yl1 = floor((xy[1] - xd)*height/yreal);
+            break;
+
+            default:
+            g_return_if_reached();
+            break;
+        }
+        gdk_draw_line(drawable, layer->gc, xl0, yl0, xl1, yl1);
+
+        switch (target) {
+            case GWY_RENDERING_TARGET_SCREEN:
+            gwy_data_view_coords_real_to_xy(data_view, xy[2] + xd, xy[3] + yd,
+                                            &xl0, &yl0);
+            gwy_data_view_coords_real_to_xy(data_view, xy[2] - xd, xy[3] - yd,
+                                            &xl1, &yl1);
+            gwy_data_view_coords_xy_cut_line(data_view, &xl0, &yl0, &xl1, &yl1);
+            break;
+
+            case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
+            xl0 = floor((xy[2] + xd)*width/xreal);
+            yl0 = floor((xy[3] + xd)*height/yreal);
+            xl1 = floor((xy[2] - xd)*width/xreal);
+            yl1 = floor((xy[3] - xd)*height/yreal);
+            break;
+
+            default:
+            g_return_if_reached();
+            break;
+        }
+        gdk_draw_line(drawable, layer->gc, xl0, yl0, xl1, yl1);
+    }
+
     if (!layer_line->line_numbers)
         return;
 
@@ -361,7 +469,6 @@ gwy_layer_line_draw_object(GwyVectorLayer *layer,
 
         case GWY_RENDERING_TARGET_PIXMAP_IMAGE:
         gwy_data_view_get_pixel_data_sizes(data_view, &xi1, &yi1);
-        gdk_drawable_get_size(drawable, &width, &height);
         zoom = sqrt(((gdouble)(width*height))/(xi1*yi1));
 
         gwy_layer_line_draw_label(layer, drawable, zoom, i, xt, yt);
