@@ -1,5 +1,5 @@
 /*
- *  @(%) $Id: plugin-proxy.c 7500 2007-02-07 22:24:20Z yeti-dn $
+ *  @(%) $Id: plugin-proxy.c 8690 2007-12-07 09:11:33Z yeti-dn $
  *  Copyright (C) 2003,2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1402,7 +1402,7 @@ text_dump_import(gchar *buffer,
         memcpy(d, pos, n);
 #else
         gwy_byteswapped_copy(pos, (guint8*)d,
-                             sizeof(gdouble), n, sizeof(gdouble)-1);
+                             sizeof(gdouble), xres*yres, sizeof(gdouble)-1);
 #endif
         pos += n;
         val = gwy_str_next_line(&pos);
