@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: calibrate.c 8718 2008-03-29 18:04:42Z miraval $
+ *  @(#) $Id: calibrate.c 8875 2008-12-28 12:16:30Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -121,7 +121,8 @@ static void        calibrate_save_args       (GwyContainer *container,
 static void        units_change_cb           (GtkWidget *button,
                                               CalibrateControls *controls);
 static void        set_combo_from_unit       (GtkWidget *combo,
-                                              const gchar *str);
+                                              const gchar *str,
+                                              gint basepower);
 
 static const CalibrateArgs calibrate_defaults = {
     1.0,
@@ -139,7 +140,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Recalibrates scan lateral dimensions or value range."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.6",
+    "2.7",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -197,10 +198,12 @@ calibrate(GwyContainer *data, GwyRunType run)
     args.x0 = args.x0orig;
     args.y0 = args.y0orig;
     siunitxy = gwy_data_field_get_si_unit_xy(dfields[0]);
-    args.xyunitorig = gwy_si_unit_get_string(siunitxy, GWY_SI_UNIT_FORMAT_VFMARKUP);
+    args.xyunitorig = gwy_si_unit_get_string(siunitxy,
+                                             GWY_SI_UNIT_FORMAT_VFMARKUP);
     args.xyunit = args.xyunitorig;
     siunitz = gwy_data_field_get_si_unit_z(dfields[0]);
-    args.zunitorig = gwy_si_unit_get_string(siunitz, GWY_SI_UNIT_FORMAT_VFMARKUP);
+    args.zunitorig = gwy_si_unit_get_string(siunitz,
+                                            GWY_SI_UNIT_FORMAT_VFMARKUP);
     args.zunit = args.zunitorig;
 
     if (run == GWY_RUN_INTERACTIVE) {
@@ -212,23 +215,19 @@ calibrate(GwyContainer *data, GwyRunType run)
 
     dfields[0] = gwy_data_field_duplicate(dfields[0]);
 
-    if (args.xreal != args.xorig)
-        gwy_data_field_set_xreal(dfields[0], args.xreal);
-    if (args.yreal != args.yorig)
-        gwy_data_field_set_yreal(dfields[0], args.yreal);
+    gwy_data_field_set_xreal(dfields[0], args.xreal);
+    gwy_data_field_set_yreal(dfields[0], args.yreal);
     if (args.zratio != 1.0)
         gwy_data_field_multiply(dfields[0], args.zratio);
-    if (args.x0 != args.x0orig)
-        gwy_data_field_set_xoffset(dfields[0], args.x0);
-    if (args.y0 != args.y0orig)
-        gwy_data_field_set_yoffset(dfields[0], args.y0);
+    gwy_data_field_set_xoffset(dfields[0], args.x0);
+    gwy_data_field_set_yoffset(dfields[0], args.y0);
     if (args.xyunit != args.xyunitorig) {
+        siunitxy = gwy_data_field_get_si_unit_xy(dfields[0]);
         gwy_si_unit_set_from_string(siunitxy, args.xyunit);
-        gwy_data_field_set_si_unit_xy(dfields[0], siunitxy);
     }
     if (args.zunit != args.zunitorig) {
-      gwy_si_unit_set_from_string(siunitz, args.zunit);
-      gwy_data_field_set_si_unit_z(dfields[0], siunitz);
+        siunitz = gwy_data_field_get_si_unit_z(dfields[0]);
+        gwy_si_unit_set_from_string(siunitz, args.zunit);
     }
 
     if (dfields[1]) {
@@ -237,6 +236,10 @@ calibrate(GwyContainer *data, GwyRunType run)
         gwy_data_field_set_yreal(dfields[1], args.yreal);
         gwy_data_field_set_xoffset(dfields[1], args.x0);
         gwy_data_field_set_xoffset(dfields[1], args.y0);
+        if (args.xyunit != args.xyunitorig) {
+            siunitxy = gwy_data_field_get_si_unit_xy(dfields[1]);
+            gwy_si_unit_set_from_string(siunitxy, args.xyunit);
+        }
     }
 
     if (dfields[2]) {
@@ -245,6 +248,10 @@ calibrate(GwyContainer *data, GwyRunType run)
         gwy_data_field_set_yreal(dfields[2], args.yreal);
         gwy_data_field_set_xoffset(dfields[2], args.x0);
         gwy_data_field_set_xoffset(dfields[2], args.y0);
+        if (args.xyunit != args.xyunitorig) {
+            siunitxy = gwy_data_field_get_si_unit_xy(dfields[2]);
+            gwy_si_unit_set_from_string(siunitxy, args.xyunit);
+        }
     }
 
     newid = gwy_app_data_browser_add_data_field(dfields[0], data, TRUE);
@@ -289,7 +296,7 @@ calibrate_dialog(CalibrateArgs *args,
     controls.args = args;
     controls.in_update = TRUE;
 
-    table = gtk_table_new(13, 3, FALSE);
+    table = gtk_table_new(13, 4, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -319,7 +326,13 @@ calibrate_dialog(CalibrateArgs *args,
         = gwy_combo_box_metric_unit_new(G_CALLBACK(xyexponent_changed_cb),
                                         &controls, -15, 6, unit,
                                         args->xyexponent);
-    gtk_table_attach(GTK_TABLE(table), controls.xyexponent, 2, 3, row, row+1,
+    gtk_table_attach(GTK_TABLE(table), controls.xyexponent, 2, 3, row, row+2,
+                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+
+    controls.xyunits = gtk_button_new_with_label(_("Change"));
+    g_object_set_data(G_OBJECT(controls.xyunits), "id", (gpointer)"xy");
+    gtk_table_attach(GTK_TABLE(table), controls.xyunits,
+                     3, 4, row, row+2,
                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
     row++;
 
@@ -334,10 +347,6 @@ calibrate_dialog(CalibrateArgs *args,
     gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
     gtk_table_attach(GTK_TABLE(table), spin,
                      1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    controls.xyunits = gtk_button_new_with_label(_("Change"));
-    g_object_set_data(G_OBJECT(controls.xyunits), "id", (gpointer)"xy");
-    gtk_table_attach(GTK_TABLE(table), controls.xyunits,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
     row++;
 
     controls.square
@@ -389,7 +398,7 @@ calibrate_dialog(CalibrateArgs *args,
     spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.zreal), 1, 2);
     gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
     gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+2, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
     unit = gwy_data_field_get_si_unit_z(dfield);
     controls.zexponent
@@ -398,12 +407,12 @@ calibrate_dialog(CalibrateArgs *args,
                                         args->zexponent);
     gtk_table_attach(GTK_TABLE(table), controls.zexponent, 2, 3, row, row+1,
                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
-    row++;
 
     controls.zunits = gtk_button_new_with_label(_("Change"));
     g_object_set_data(G_OBJECT(controls.zunits), "id", (gpointer)"z");
     gtk_table_attach(GTK_TABLE(table), controls.zunits,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+                     3, 4, row, row+1,
+                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
 
     row++;
 
@@ -499,24 +508,34 @@ dialog_reset(CalibrateControls *controls,
 {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->square),
                                  calibrate_defaults.square);
+
+    set_combo_from_unit(controls->xyexponent,
+                        args->xyunitorig, args->xyorigexp);
     gwy_enum_combo_box_set_active(GTK_COMBO_BOX(controls->xyexponent),
                                   args->xyorigexp);
-    args->xyexponent = args->xyorigexp;
-    set_combo_from_unit(controls->xyexponent, args->xyunitorig);
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->xreal),
+                             args->xorig/pow10(args->xyorigexp));
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->yreal),
+                             args->yorig/pow10(args->xyorigexp));
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->yratio),
                              calibrate_defaults.yratio);
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->xratio),
                              calibrate_defaults.xratio);
+
+    set_combo_from_unit(controls->zexponent,
+                        args->zunitorig, args->zorigexp);
     gwy_enum_combo_box_set_active(GTK_COMBO_BOX(controls->zexponent),
                                   args->zorigexp);
-    args->zexponent = args->zorigexp;
-    set_combo_from_unit(controls->zexponent, args->zunitorig);
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->zreal),
+                             args->zorig/pow10(args->zorigexp));
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->zratio),
                              calibrate_defaults.zratio);
+
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->x0),
                              args->x0orig/pow10(args->xyexponent));
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->y0),
                              args->y0orig/pow10(args->xyexponent));
+
     calibrate_dialog_update(controls, args);
 }
 
@@ -739,71 +758,74 @@ static void
 units_change_cb(GtkWidget *button,
                 CalibrateControls *controls)
 {
-  GtkWidget *dialog, *hbox, *label, *entry;
-  const gchar *id, *unit;
-  gint response;
-  CalibrateArgs *args = controls->args;
+    GtkWidget *dialog, *hbox, *label, *entry;
+    const gchar *id, *unit;
+    gint response;
+    CalibrateArgs *args = controls->args;
 
-  if (controls->in_update)
-    return;
+    if (controls->in_update)
+        return;
 
-  controls->in_update = TRUE;
+    controls->in_update = TRUE;
 
-  id = g_object_get_data(G_OBJECT(button), "id");
-  dialog = gtk_dialog_new_with_buttons(_("Change Units"),
-                                       NULL,
-                                           GTK_DIALOG_MODAL
-                                               | GTK_DIALOG_NO_SEPARATOR,
-                                               GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                               GTK_STOCK_OK, GTK_RESPONSE_OK,
-                                               NULL);
-  gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
+    id = g_object_get_data(G_OBJECT(button), "id");
+    dialog = gtk_dialog_new_with_buttons(_("Change Units"),
+                                         NULL,
+                                         GTK_DIALOG_MODAL
+                                         | GTK_DIALOG_NO_SEPARATOR,
+                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                         GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                         NULL);
+    gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
 
-  hbox = gtk_hbox_new(FALSE, 6);
-  gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox,
-                     FALSE, FALSE, 0);
+    hbox = gtk_hbox_new(FALSE, 6);
+    gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox,
+                       FALSE, FALSE, 0);
 
-  label = gtk_label_new_with_mnemonic(_("New _units:"));
-  gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
+    label = gtk_label_new_with_mnemonic(_("New _units:"));
+    gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
 
-  entry = gtk_entry_new();
-  gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
+    entry = gtk_entry_new();
+    gtk_entry_set_activates_default(GTK_ENTRY(entry), TRUE);
+    gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
+
+    gtk_widget_show_all(dialog);
+    response = gtk_dialog_run(GTK_DIALOG(dialog));
+    if (response != GTK_RESPONSE_OK) {
+        gtk_widget_destroy(dialog);
+        return;
+    }
+
+    unit = gtk_entry_get_text(GTK_ENTRY(entry));
+    if (gwy_strequal(id, "xy")) {
+        set_combo_from_unit(controls->xyexponent, unit, 0);
+        controls->args->xyunit = g_strdup(unit);
+    }
+    else if (gwy_strequal(id, "z")) {
+        set_combo_from_unit(controls->zexponent, unit, 0);
+        controls->args->zunit = g_strdup(unit);
+    }
 
-  gtk_widget_show_all(dialog);
-  response = gtk_dialog_run(GTK_DIALOG(dialog));
-  if (response != GTK_RESPONSE_OK) {
     gtk_widget_destroy(dialog);
-    return;
-  }
 
-  unit = gtk_entry_get_text(GTK_ENTRY(entry));
-  if (gwy_strequal(id, "xy")) {
-    set_combo_from_unit(controls->xyexponent, unit);
-    controls->args->xyunit = g_strdup(unit);
-  }
-  else if (gwy_strequal(id, "z")) {
-    set_combo_from_unit(controls->zexponent, unit);
-    controls->args->zunit = g_strdup(unit);
-  }
-
-  gtk_widget_destroy(dialog);
-
-  calibrate_dialog_update(controls, args);
-  controls->in_update = FALSE;
+    calibrate_dialog_update(controls, args);
+    controls->in_update = FALSE;
 }
 
 static void
 set_combo_from_unit(GtkWidget *combo,
-                    const gchar *str)
+                    const gchar *str,
+                    gint basepower)
 {
-  GwySIUnit *unit;
-  gint power10;
+    GwySIUnit *unit;
+    gint power10;
 
-  unit = gwy_si_unit_new_parse(str, &power10);
-  gwy_combo_box_metric_unit_set_unit(GTK_COMBO_BOX(combo),
-                                     power10 - 6, power10 + 6, unit);
-  g_object_unref(unit);
+    unit = gwy_si_unit_new_parse(str, &power10);
+    power10 += basepower;
+    gwy_combo_box_metric_unit_set_unit(GTK_COMBO_BOX(combo),
+                                       power10 - 6, power10 + 6, unit);
+    g_object_unref(unit);
 }
 
 static void
