@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: drift.c 8882 2008-12-28 12:17:25Z yeti-dn $
+ *  @(#) $Id: drift.c 8983 2009-01-24 17:22:34Z yeti-dn $
  *  Copyright (C) 2007,2008 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -278,7 +278,7 @@ drift_dialog(DriftArgs *args,
     row = 0;
 
     controls.range = gtk_adjustment_new(args->range, 1.0, 50.0, 1.0, 5.0, 0);
-    spin = gwy_table_attach_hscale(table, row, "_Search range:", "rows",
+    spin = gwy_table_attach_hscale(table, row, _("_Search range:"), _("rows"),
                                    controls.range, GWY_HSCALE_DEFAULT);
     g_signal_connect(controls.range, "value-changed",
                      G_CALLBACK(drift_invalidate), &controls);
