@@ -303,7 +303,7 @@ static GwyModuleInfo module_info = {
     (GwyModuleRegisterFunc) &module_register,
     N_("Analyses nanoindentation structure (volumes, surfaces, ...)."),
     "Lukáš Chvátal <chvatal@physics.muni.cz>",
-    "0.1.1",
+    "0.1.2",
     "Lukáš Chvátal",
     "2005",
 };
@@ -454,18 +454,18 @@ create_parameters_table(IndentAnalyzeControls * controls)
          GTK_OBJECT(controls->w_how_mark), GWY_HSCALE_WIDGET);
    
    controls->w_plane_tol = gtk_adjustment_new(args->plane_tol, 0, 100, 0.1, 1,
-         10);
+                                              0);
    gwy_table_attach_hscale(table, row++, _("Ref. plane _tolerance:"), "%",
          controls->w_plane_tol, 0);
    
-   controls->w_phi_tol = gtk_adjustment_new(args->phi_tol, 0, 180, 0.1, 10, 10);
-   gwy_table_attach_hscale(table, row++, _("Angle _1 tolerance:"), "deg",
+   controls->w_phi_tol = gtk_adjustment_new(args->phi_tol, 0, 180, 0.1, 10, 0);
+   gwy_table_attach_hscale(table, row++, _("Angle _1 tolerance:"), _("deg"),
          controls->w_phi_tol, 0);
    
    /* XXX: what the hell is this for?
     controls.w_theta_tol = gtk_adjustment_new(args->theta_tol,
-    0, 90, 0.1, 10, 10);
-    spin = gwy_table_attach_hscale(table, row, _("T_heta range:"), "deg",
+    0, 90, 0.1, 10, 0);
+    spin = gwy_table_attach_hscale(table, row, _("T_heta range:"), _("deg"),
     controls.w_theta_tol, 0);
     row++;
     */
@@ -913,7 +913,7 @@ level_data(IndentAnalyzeControls *c)
             gwy_data_field_plane_rotate(dfield,
                                 180/G_PI*atan2(args->plane_x, 1),
                                 180/G_PI*atan2(args->plane_y, 1),
-                                GWY_INTERPOLATION_BILINEAR);
+                                GWY_INTERPOLATION_LINEAR);
             break;
     }
 */
@@ -1288,7 +1288,6 @@ indent_analyze_ok(GwyContainer *data, IndentAnalyzeControls * controls)
 {
     //GwyDataField *dfield;
     GObject *maskfield;
-    gint dfield_id = 0;
     GString *mask_name = g_string_new("");
     
     // get right ID of datafield    
