@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: distance.c 8877 2008-12-28 12:16:44Z yeti-dn $
+ *  @(#) $Id: distance.c 8993 2009-02-04 11:24:11Z yeti-dn $
  *  Copyright (C) 2003-2008 Nenad Ocelic, David Necas (Yeti), Petr Klapetek.
  *  E-mail: ocelic@biochem.mpg.de, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -91,7 +91,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Distance measurement tool, measures distances and angles."),
     "Nenad Ocelic <ocelic@biochem.mpg.de>",
-    "2.9",
+    "2.10",
     "Nenad Ocelic & David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -224,7 +224,7 @@ gwy_tool_distance_init_dialog(GwyToolDistance *tool)
 
     tool->copy = gwy_tool_distance_add_aux_button(tool, GTK_STOCK_COPY,
                                                   _("Copy table to clipboard"));
-    g_signal_connect_swapped(tool->save, "clicked",
+    g_signal_connect_swapped(tool->copy, "clicked",
                              G_CALLBACK(gwy_tool_distance_copy), tool);
 
     gwy_plain_tool_add_clear_button(GWY_PLAIN_TOOL(tool));
@@ -432,11 +432,11 @@ gwy_tool_distance_render_cell(GtkCellLayout *layout,
         {
             gint x, y;
 
-            x = gwy_data_field_rtoj(plain_tool->data_field, line[2]);
-            y = gwy_data_field_rtoi(plain_tool->data_field, line[3]);
+            x = floor(gwy_data_field_rtoj(plain_tool->data_field, line[2]));
+            y = floor(gwy_data_field_rtoi(plain_tool->data_field, line[3]));
             val = gwy_data_field_get_val(plain_tool->data_field, x, y);
-            x = gwy_data_field_rtoj(plain_tool->data_field, line[0]);
-            y = gwy_data_field_rtoi(plain_tool->data_field, line[1]);
+            x = floor(gwy_data_field_rtoj(plain_tool->data_field, line[0]));
+            y = floor(gwy_data_field_rtoi(plain_tool->data_field, line[1]));
             val -= gwy_data_field_get_val(plain_tool->data_field, x, y);
             vf = plain_tool->value_format;
         }
@@ -471,13 +471,11 @@ gwy_tool_distance_copy(GwyToolDistance *tool)
 {
     GtkClipboard *clipboard;
     GdkDisplay *display;
-    GdkAtom atom;
     gchar *text;
 
     text = gwy_tool_distance_create_report(tool);
-    atom = gdk_atom_intern("CLIPBOARD", FALSE);
     display = gtk_widget_get_display(GTK_WIDGET(GWY_TOOL(tool)->dialog));
-    clipboard = gtk_clipboard_get_for_display(display, atom);
+    clipboard = gtk_clipboard_get_for_display(display, GDK_SELECTION_CLIPBOARD);
     gtk_clipboard_set_text(clipboard, text, -1);
     g_free(text);
 }
@@ -518,11 +516,11 @@ gwy_tool_distance_create_report(GwyToolDistance *tool)
         vf_phi = tool->angle_format;
         val_phi = atan2(line[1] - line[3], line[2] - line[0]) * 180.0/G_PI;
 
-        x = gwy_data_field_rtoj(plain_tool->data_field, line[2]);
-        y = gwy_data_field_rtoi(plain_tool->data_field, line[3]);
+        x = floor(gwy_data_field_rtoj(plain_tool->data_field, line[2]));
+        y = floor(gwy_data_field_rtoi(plain_tool->data_field, line[3]));
         val_dz = gwy_data_field_get_val(plain_tool->data_field, x, y);
-        x = gwy_data_field_rtoj(plain_tool->data_field, line[0]);
-        y = gwy_data_field_rtoi(plain_tool->data_field, line[1]);
+        x = floor(gwy_data_field_rtoj(plain_tool->data_field, line[0]));
+        y = floor(gwy_data_field_rtoi(plain_tool->data_field, line[1]));
         val_dz -= gwy_data_field_get_val(plain_tool->data_field, x, y);
         vf_dz = plain_tool->value_format;
 
