@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: roughness.c 8878 2008-12-28 12:16:51Z yeti-dn $
+ *  @(#) $Id: roughness.c 8993 2009-02-04 11:24:11Z yeti-dn $
  *  Copyright (C) 2006-2008 Martin Hason, David Necas (Yeti), Petr Klapetek.
  *  E-mail: hasonm@physics.muni.cz, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -630,7 +630,7 @@ static GwyModuleInfo module_info = {
     N_("Calculate surface profile parameters."),
     "Martin Hasoň <hasonm@physics.muni.cz>, "
         "Yeti <yeti@gwyddion.net>",
-    "1.3",
+    "1.4",
     "Martin Hasoň & David Nečas (Yeti)",
     "2006",
 };
@@ -836,7 +836,7 @@ gwy_tool_roughness_init_dialog(GwyToolRoughness *tool)
 
     tool->copy = gwy_tool_roughness_add_aux_button(tool, GTK_STOCK_COPY,
                                                   _("Copy table to clipboard"));
-    g_signal_connect_swapped(tool->save, "clicked",
+    g_signal_connect_swapped(tool->copy, "clicked",
                              G_CALLBACK(gwy_tool_roughness_copy), tool);
 
     table = gtk_table_new(4, 4, FALSE);
@@ -1280,10 +1280,10 @@ gwy_tool_roughness_update(GwyToolRoughness *tool)
     g_return_if_fail(plain_tool->selection);
     g_return_if_fail(gwy_selection_get_object(plain_tool->selection, 0, line));
 
-    xl1 = (gint)gwy_data_field_rtoj(plain_tool->data_field, line[0]);
-    yl1 = (gint)gwy_data_field_rtoi(plain_tool->data_field, line[1]);
-    xl2 = (gint)gwy_data_field_rtoj(plain_tool->data_field, line[2]);
-    yl2 = (gint)gwy_data_field_rtoi(plain_tool->data_field, line[3]);
+    xl1 = floor(gwy_data_field_rtoj(plain_tool->data_field, line[0]));
+    yl1 = floor(gwy_data_field_rtoi(plain_tool->data_field, line[1]));
+    xl2 = floor(gwy_data_field_rtoj(plain_tool->data_field, line[2]));
+    yl2 = floor(gwy_data_field_rtoi(plain_tool->data_field, line[3]));
 
     lineres = ROUND(hypot(xl1 - xl2, yl1 - yl2));
     if (lineres < 8)
@@ -2156,7 +2156,6 @@ gwy_tool_roughness_copy(GwyToolRoughness *tool)
     ToolReportData report_data;
     GtkClipboard *clipboard;
     GdkDisplay *display;
-    GdkAtom atom;
     gssize len;
     gchar *text;
 
@@ -2174,9 +2173,8 @@ gwy_tool_roughness_copy(GwyToolRoughness *tool)
     report_data.id = plain_tool->id;
 
     text = gwy_tool_roughness_create_report(&report_data, &len);
-    atom = gdk_atom_intern("CLIPBOARD", FALSE);
     display = gtk_widget_get_display(GTK_WIDGET(GWY_TOOL(tool)->dialog));
-    clipboard = gtk_clipboard_get_for_display(display, atom);
+    clipboard = gtk_clipboard_get_for_display(display, GDK_SELECTION_CLIPBOARD);
     gtk_clipboard_set_text(clipboard, text, -1);
     g_free(text);
 
@@ -2227,13 +2225,13 @@ gwy_tool_roughness_create_report(gpointer user_data,
 
     for (i = 0; i < 4; i++) {
         if (i % 2 == 0) {
-            k = (gint)gwy_data_field_rtoj(report_data->data_field,
-                                          report_data->line[i]);
+            k = floor(gwy_data_field_rtoj(report_data->data_field,
+                                          report_data->line[i]));
             x = report_data->line[i] + xoff;
         }
         else {
-            k = (gint)gwy_data_field_rtoi(report_data->data_field,
-                                          report_data->line[i]);
+            k = floor(gwy_data_field_rtoi(report_data->data_field,
+                                          report_data->line[i]));
             x = report_data->line[i] + yoff;
         }
         linepx[i] = g_strdup_printf("%d", k);
